View source: R/verb-maximise.R
| maximise | R Documentation |
For a collection of distributions, this function provides the distribution of the maximum value from independent draws of each component distribution.
maximise(..., draws = 1)
maximize(..., draws = 1)
... |
Distribution objects, possibly also lists of distributions. |
draws |
Number of draws from each distribution considered in the
maximum. Either a single numeric applying to all distributions in |
To use precise language, if X1, ..., Xp are
p independent random variables corresponding to the distributions
in ..., then the distribution returned is of max(X1, ..., Xp).
A distribution of class "max".
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.