View source: R/verb-minimise.R
| minimise | R Documentation |
For a collection of distributions, this function provides the distribution of the minimum value from independent draws of each component distribution.
minimise(..., draws = 1)
minimize(..., draws = 1)
... |
Distribution objects, possibly also lists of distributions. |
draws |
Number of draws from each distribution considered in the
minimum. Either a single numeric applying to all distributions in |
To use precise language, if X1, ..., Xp are
p independent random variables corresponding to the distributions
in ..., then the distribution returned is of min(X1, ..., Xp).
A distribution of class "min".
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.