| Ops.finite | R Documentation |
Ops for a Finite Distribution
## S3 method for class 'finite'
Ops(e1, e2)
e1, e2 |
Objects on the left- and right-hand sides of a binary
operator, or in the case of a unary operator, |
Although the default Ops for distributions is defined as a wrapper
around the verbs shift(), multiply(), flip(), and invert(),
the opposite is true for "finite" distributions. This is so that
Ops.finite() can piggyback off of the Ops defined on the vector
of finite observations.
A transformed distribution. This turns out to be another
finite distribution, with the original outcomes transformed
by the specified Ops.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.